@@ -1,7 +1,9 @@
 use super::schema;
 use crate::client::schema::ConversionError;
 use crate::client::schema::ConversionError::HexStringPrefixError;
+use core::fmt;
 use cynic::impl_scalar;
+use fuel_tx::InstructionResult;
 use serde::de::Error;
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
 use std::fmt::{Debug, Display, Formatter, LowerHex};
@@ -110,6 +112,12 @@ impl From<UtxoId> for fuel_tx::UtxoId {
     }
 }
 
+impl LowerHex for UtxoId {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
+        LowerHex::fmt(&self.0 .0, f)
+    }
+}
+
 #[derive(cynic::Scalar, Debug, Clone)]
 pub struct HexString(pub Bytes);
 
@@ -188,3 +196,9 @@ impl From<usize> for U64 {
         U64(i as u64)
     }
 }
+
+impl From<U64> for InstructionResult {
+    fn from(s: U64) -> Self {
+        s.0.into()
+    }
+}
